#!/bin/bash
############################################################################
# Group Trial Cron Script 0.3 by Turranius                                 #
# This script will check how much users in a group uploaded this week or   #
# month and add it togheter. It supports up to 9 stat sections.            # 
# This is the script ment to be run as a cron job to create a log file.    #
# Otherwise, you would have to use the trialgroup.sh before midnight at    #
# saturday night. With this you can just check the logfile. It basically   #
# runs trialgroup.sh for you.                                              #
# Copy this to /glftpd/bin and set crontab to                              #
# 55 23 * * 6 /glftpd/bin/trialgroup.cron.sh                               #
# This will run it at 23:55 on Saturday.                                   #
# Setup the parameters below. If you have any folders in your              #
# users folder, add them to the EXLUDE line, | delimited. You can also     #
# add any users you do not want to count, even if they are in a group with #
# trial.                                                                   #
# Try to run it from shell and check the logfile.                          #
############################################################################
# Changelog                                                                #
# 0.1 - Initial script.                                                    #
# 0.2 - Added TRiAL-2 which is to be used if they are up for trial next    #
#       week. Have to change it to TRiAL manually when its time for them   #
#       to start. Nice to know how they are doing.                         #
#       Changed how the script checks if they are on trial. Instead of     #
#       reading a file, it checks the groups NFO. To set groups on trial   #
#       change the groups nfo (with site grpnfo) to either TRiAL or        #
#       TRiAL-2.                                                           #
# 0.3 - Add: Supports up to 9 stat sections.                               #
#       Add: Supports both weekly and monthly trials.                      #
#       Fix: The header for each group found was not writted to logfile.   #
#                                                                          #
############################################################################

USERPATH=/glftpd/ftp-data/users                  # Full path to users folder.
GROUPFILE=/glftpd/etc/group                      # Full path to groups file.
LOGFILE=/glftpd/ftp-data/logs/grouptrial.log     # Where do you want the log?
DURATION=W                                       # W = Weekly, M = Monthly trials.
EXCLUDE='default.user|glftpd|backup|disabled'    # If you have folders in your users
                                                 # dir, add them here. Users can
                                                 # be added too if you find a reason
                                                 # to do that.

##############################################################################
## Dont change anything below here unless you know what you are doing.       #
##############################################################################

## Do we want weekly or monthly trials?
case $DURATION in
 W)
   DUR="WKUP"
   DURNAME="week"
   ;;
 M)
   DUR="MONTHUP"
   DURNAME="month"
   ;;
 *)
   echo "Duration not set right. Either W or M"
   exit 0
   ;;
esac

UPPED="0"
COUNT="0"
TOTAL="0"
EXISTS="NO"
cd $USERPATH
touch $LOGFILE
DATE="$(date)"

echo "#--------------------------------------------------------#" >> $LOGFILE
echo "# $DATE" >> $LOGFILE

for i in `cat $GROUPFILE`
do
  NAME="$(echo $i | awk -F":" '{print $1}')"
  TRIAL="$(echo $i | awk -F":" '{print $2}')"
  if [ "$TRIAL" = "TRiAL" ]; then
    for u in `ls -f -A | /bin/egrep -v $EXCLUDE`
    do
      if [ "$LAST" != $i ]; then
        TOTAL="0"
        echo "#" >> $LOGFILE
        echo "#-----[ New group found: $i ]----- " >> $LOGFILE
      fi
      GROUP="$(cat $u | grep -w GROUP | awk -F" " '{print $2}')"
      INIT="$( echo -w $GROUP | grep -w $NAME )"
      if [ "$INIT" != "" ]; then
        UPPED="$(cat $u | grep -w $DUR | awk -F" " '{print $3}')"

        ## Check for other stat sections.
        UPPED2="$( grep -w $DUR $u | awk -F" " '{print $6}')"
        if [ "$UPPED2" != "" ]; then
          UPPED3="$(grep -w $DUR $u | awk -F" " '{print $9}')"
          if [ "$UPPED3" != "" ]; then
            UPPED4="$(grep -w $DUR $u | awk -F" " '{print $12}')"
            if [ "$UPPED4" != "" ]; then
              UPPED5="$(grep -w $DUR $u | awk -F" " '{print $15}')"
              if [ "$UPPED5" != "" ]; then
                UPPED6="$(grep -w $DUR $u | awk -F" " '{print $18}')"
                if [ "$UPPED6" != "" ]; then
                  UPPED7="$(grep -w $DUR $u | awk -F" " '{print $21}')"
                  if [ "$UPPED7" != "" ]; then
                    UPPED8="$(grep -w $DUR $u | awk -F" " '{print $24}')"
                    if [ "$UPPED8" != "" ]; then
                      UPPED9="$(grep -w $DUR $u | awk -F" " '{print $27}')"
                      if [ "$UPPED9" != "" ]; then
                        UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" \+ "$UPPED6" \+ "$UPPED7" \+ "$UPPED8" \+ "$UPPED9" )"
                      else
                        UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" \+ "$UPPED6" \+ "$UPPED7" \+ "$UPPED8" )"
                      fi
                    else
                      UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" \+ "$UPPED6" \+ "$UPPED7" )"
                    fi
                  else
                    UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" \+ "$UPPED6" )"
                  fi
                else
                  UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" )"
                fi
              else
                UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" )"
              fi
            else
              UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" )"
            fi
          else
            UPPED="$( expr "$UPPED" \+ "$UPPED2" )"
          fi
        fi

        UPPED="$(expr $UPPED \/ 1024)"
        COUNT="$(expr $COUNT \+ 1)"
        TOTAL="$(expr $UPPED \+ $TOTAL)"
        echo "# User: $u - $UPPED MB this $DURNAME. Total: $TOTAL" >> $LOGFILE
      fi
      LAST=$i
    done
  fi
done

## NEXT WEEKS PERIOD
i=""
u=""

for i in `cat $GROUPFILE`
do
  NAME="$(echo $i | awk -F":" '{print $1}')"
  TRIAL2="$(echo $i | awk -F":" '{print $2}')"
  if [ "$TRIAL2" = "TRiAL-2" ]; then
    for u in `ls -f -A | /bin/egrep -v $EXCLUDE`
    do
      if [ "$LAST" != $i ]; then
        TOTAL="0"
        echo "#" >> $LOGFILE
        echo "#-----[ Found group for next $DURNAME: $i ]----- " >> $LOGFILE
      fi
      GROUP="$(cat $u | grep -w GROUP | awk -F" " '{print $2}')"
      INIT="$( echo $GROUP | grep -w $NAME )"
      if [ "$INIT" != "" ]; then
        UPPED="$(cat $u | grep -w $DUR | awk -F" " '{print $3}')"

        ## Check for other stat sections.
        UPPED2="$( grep -w $DUR $u | awk -F" " '{print $6}')"
        if [ "$UPPED2" != "" ]; then
          UPPED3="$(grep -w $DUR $u | awk -F" " '{print $9}')"
          if [ "$UPPED3" != "" ]; then
            UPPED4="$(grep -w $DUR $u | awk -F" " '{print $12}')"
            if [ "$UPPED4" != "" ]; then
              UPPED5="$(grep -w $DUR $u | awk -F" " '{print $15}')"
              if [ "$UPPED5" != "" ]; then
                UPPED6="$(grep -w $DUR $u | awk -F" " '{print $18}')"
                if [ "$UPPED6" != "" ]; then
                  UPPED7="$(grep -w $DUR $u | awk -F" " '{print $21}')"
                  if [ "$UPPED7" != "" ]; then
                    UPPED8="$(grep -w $DUR $u | awk -F" " '{print $24}')"
                    if [ "$UPPED8" != "" ]; then
                      UPPED9="$(grep -w $DUR $u | awk -F" " '{print $27}')"
                      if [ "$UPPED9" != "" ]; then
                        UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" \+ "$UPPED6" \+ "$UPPED7" \+ "$UPPED8" \+ "$UPPED9" )"
                      else
                        UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" \+ "$UPPED6" \+ "$UPPED7" \+ "$UPPED8" )"
                      fi
                    else
                      UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" \+ "$UPPED6" \+ "$UPPED7" )"
                    fi
                  else
                    UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" \+ "$UPPED6" )"
                  fi
                else
                  UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" \+ "$UPPED5" )"
                fi
              else
                UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" \+ "$UPPED4" )"
              fi
            else
              UPPED="$( expr "$UPPED" \+ "$UPPED2" \+ "$UPPED3" )"
            fi
          else
            UPPED="$( expr "$UPPED" \+ "$UPPED2" )"
          fi
        fi

        UPPED="$(expr $UPPED \/ 1024)"
        COUNT="$(expr $COUNT \+ 1)"
        TOTAL="$(expr $UPPED \+ $TOTAL)"
        echo "# User: $u - $UPPED MB this $DURNAME. Total: $TOTAL" >> $LOGFILE
      fi
      LAST=$i
    done
  fi
done
echo "#--------------------------------------------------------#" >> $LOGFILE
echo "# End of group trial $DURNAME " >> $LOGFILE
echo " " >> $LOGFILE
exit 0
